@@ -129,4 +129,26 @@ class xml(object):
 		if present:
 			return xml_node(root)
 		else:
-			raise NameError(f"unknown root node: '{name}'")
\ No newline at end of file
+			raise NameError(f"unknown root node: '{name}'")
+
+	def add_root_node(self: object, name: str, attrs: dict = {}, value: str = ""):
+		"""
+		Adds new root node.
+		"""
+		available = True
+
+		for item in self.__list:
+			if item["name"] == name:
+				available = False
+
+				break
+
+		if not available:
+			raise NameError(f"root node '{name}' already exists")
+		else:
+			self.__list.append({
+				"name": name,
+				"attrs": attrs,
+				"child": [],
+				"value": value
+			})
\ No newline at end of file
